@@ -32,11 +32,15 @@ screeplot.MultivariateAnalysis <- function(x, ..., eigenvalues = FALSE, cumulati
   if (eigenvalues) {
     data$y <- data[[1L]]
     data$labels <- round(data$y, digits = 1)
-    ylab <- "Eigenvalues"
+    ylab <- tr_("Eigenvalues")
   } else {
     data$y <- data[[2L]]
     data$labels <- paste0(round(data$y, digits = 1), "%")
-    ylab <- if (methods::is(x, "CA")) "Inertia" else "Explained variance (%)"
+    if (methods::is(x, "CA")) {
+      ylab <- tr_("Proportion of inertia (%)")
+    } else {
+      ylab <- tr_("Explained variance (%)")
+    }
   }
 
   k <- max(data$y) / max(data$z)
@@ -66,6 +70,11 @@ screeplot.MultivariateAnalysis <- function(x, ..., eigenvalues = FALSE, cumulati
   }
 
   if (cumulative && !horiz) {
+    if (methods::is(x, "CA")) {
+      ylab2 <- tr_("Cumulative inertia (%)")
+    } else {
+      ylab2 <- tr_("Cumulative variance (%)")
+    }
     tick_labels <- seq(from = 0, to = 100, by = 20)
     tick_at <- tick_labels * k
     graphics::lines(
@@ -81,7 +90,7 @@ screeplot.MultivariateAnalysis <- function(x, ..., eigenvalues = FALSE, cumulati
                    col = col.cumulative, col.ticks = col.cumulative,
                    col.axis = col.cumulative, las = 1)
     graphics::mtext(
-      text = sprintf("Cumulative percentage of %s", tolower(ylab)),
+      text = ylab2,
       side = 4, line = 3, col = col.cumulative
     )
   }
@@ -114,7 +123,7 @@ screeplot.PCOA <- function(x, ..., labels = FALSE, limit = NULL,
   }
 
   ## Bar plot
-  ylab <- "Eigenvalues"
+  ylab <- tr_("Eigenvalues")
   mid <- graphics::barplot(
     height = data$y,
     names.arg = data$x,
