@@ -213,7 +213,7 @@ setMethod(
     }
 
     ## Legend
-    prepare_legend(coord, legend, points = FALSE, lines = TRUE)
+    viz_legend(coord, legend, points = FALSE, lines = TRUE)
 
     invisible(x)
   }
@@ -374,12 +374,9 @@ viz_points <- function(x, margin, axes, ...,
     )
   }
 
-  group <- coord$extra_quali
-  if (all(is.na(group))) group[] <- ""
-
   ## Add ellipse
   if (is.list(ellipse) && length(ellipse) > 0) {
-    args_ell <- list(x = x, group = group,
+    args_ell <- list(x = x, group = extra_quali,
                      color = color, fill = FALSE, symbol = FALSE)
     ellipse <- modifyList(args_ell, val = ellipse)
     do.call(viz_ellipses, ellipse)
@@ -387,17 +384,28 @@ viz_points <- function(x, margin, axes, ...,
 
   ## Add convex hull
   if (isTRUE(hull)) {
-    args_hull <- list(x = x, group = group,
+    args_hull <- list(x = x, group = extra_quali,
                       color = color, fill = FALSE, symbol = FALSE)
     do.call(viz_hull, args_hull)
   }
 
   ## Legend
-  prepare_legend(coord, legend, points = TRUE, lines = FALSE)
+  viz_legend(coord, legend, points = TRUE, lines = FALSE)
 
   invisible(coord)
 }
 
+#' Add Legend
+#'
+#' @inheritParams prepare_legend
+#' @author N. Frerebeau
+#' @keywords internal
+viz_legend <- function(x, args, points = TRUE, lines = TRUE) {
+  leg <- prepare_legend(x, args, points = points, lines = lines)
+  if (is.null(leg)) return(invisible(NULL))
+  do.call(graphics::legend, args = leg)
+}
+
 #' Non-Overlapping Text Labels
 #'
 #' @param x A [`data.frame`] (typically returned by [prepare_plot()]).
@@ -528,6 +536,19 @@ prepare_plot <- function(x, margin, ..., axes = c(1, 2), active = TRUE,
   ## Recode
   data$observation <- ifelse(data$supplementary, "suppl.", "active")
 
+  ## Reorder
+  ## /!\ See build_results() /!\
+  origin <- get_order(x, margin = margin)
+  if (length(extra_quanti) > 1) {
+    arkhe::assert_type(extra_quanti, "numeric")
+    arkhe::assert_length(extra_quanti, n)
+    extra_quanti <- extra_quanti[origin]
+  }
+  if (length(extra_quali) > 1) {
+    arkhe::assert_length(extra_quali, n)
+    extra_quali <- extra_quali[origin]
+  }
+
   ## Set graphical parameters
   ## (recycle if of length one)
   dots <- list(...)
@@ -551,8 +572,6 @@ prepare_plot <- function(x, margin, ..., axes = c(1, 2), active = TRUE,
   }
   if (length(extra_quanti) > 0) {
     extra_quanti <- as.vector(extra_quanti)
-    arkhe::assert_type(extra_quanti, "numeric")
-    arkhe::assert_length(extra_quanti, n)
     ## Continuous scales
     ## (ignored if col, bg, cex and lwd are set by user)
     if (is.null(dots$col) && !isFALSE(color))
@@ -583,7 +602,6 @@ prepare_plot <- function(x, margin, ..., axes = c(1, 2), active = TRUE,
   }
   if (!isFALSE(extra_quali) && length(extra_quali) > 0) {
     extra_quali <- as.vector(extra_quali)
-    arkhe::assert_length(extra_quali, n)
     ## Discrete scales
     ## (ignored if col, bg, pch and lty are set by user)
     if (is.null(dots$col) && !isFALSE(color))
@@ -598,19 +616,27 @@ prepare_plot <- function(x, margin, ..., axes = c(1, 2), active = TRUE,
     extra_quali <- rep(NA_character_, n)
   }
 
+  ## Check
+  arkhe::assert_length(col, n)
+  arkhe::assert_length(bg, n)
+  arkhe::assert_length(pch, n)
+  arkhe::assert_length(cex, n)
+  arkhe::assert_length(lty, n)
+  arkhe::assert_length(lwd, n)
+
   coord <- data.frame(
     data,
     x = data[[1L]],
     y = data[[2L]],
     extra_quali = extra_quali,
     extra_quanti = extra_quanti,
-    label = data$label,
     col = col,
     bg = bg,
     pch = pch,
     cex = cex,
     lty = lty,
-    lwd = lwd
+    lwd = lwd,
+    row.names = NULL
   )
 
   ## Subset
@@ -640,25 +666,34 @@ prepare_legend <- function(x, args, points = TRUE, lines = TRUE) {
   ## Continuous scale
   if (!all(is.na(quanti))) {
     quanti <- quanti[!is.na(quanti)]
-    # im <- grDevices::as.raster(x$col)
+    solo <- !duplicated(quanti)
 
-    pr <- pretty(quanti, n = ifelse(nrow(x) > 5, 5, nrow(x)))
-    pr <- pr[pr <= max(quanti) & pr >= min(quanti)]
-    i <- order(quanti, method = "radix")
-    i <- setdiff(i, which(duplicated(quanti)))
+    if (sum(solo) > 1) {
+      pr <- pretty(quanti, n = ifelse(nrow(x) > 5, 5, nrow(x)))
+      pr <- pr[pr <= max(quanti) & pr >= min(quanti)]
+      i <- order(quanti, method = "radix")
+      i <- setdiff(i, which(duplicated(quanti)))
 
-    col <- grDevices::colorRamp(x$col[i])(scale_range(pr, from = range(quanti)))
-    col <- grDevices::rgb(col, maxColorValue = 255)
+      col <- grDevices::colorRamp(x$col[i])(scale_range(pr, from = range(quanti)))
+      col <- grDevices::rgb(col, maxColorValue = 255)
 
-    leg <- list(legend = pr, col = col)
-    if (points) {
-      k <- duplicated(quanti)
-      cex <- stats::approx(x = quanti[i], y = x$cex[i], xout = pr, ties = "ordered")$y
-      leg <- utils::modifyList(leg, list(pch = unique(x$pch), pt.cex = cex))
-    }
-    if (lines) {
-      lwd <- stats::approx(x = quanti[i], y = x$lwd[i], xout = pr, ties = "ordered")$y
-      leg <- utils::modifyList(leg, list(lty = unique(x$lty), lwd = lwd))
+      leg <- list(legend = pr, col = col)
+      if (points) {
+        cex <- stats::approx(x = quanti[i], y = x$cex[i], xout = pr, ties = "ordered")$y
+        leg <- utils::modifyList(leg, list(pch = unique(x$pch), pt.cex = cex))
+      }
+      if (lines) {
+        lwd <- stats::approx(x = quanti[i], y = x$lwd[i], xout = pr, ties = "ordered")$y
+        leg <- utils::modifyList(leg, list(lty = unique(x$lty), lwd = lwd))
+      }
+    } else {
+      leg <- list(legend = quanti[solo], col = x$col[solo])
+      if (points) {
+        leg <- utils::modifyList(leg, list(pch = x$pch[solo], pt.cex = x$cex[solo]))
+      }
+      if (lines) {
+        leg <- utils::modifyList(leg, list(lty = x$lty[solo], lwd = x$lwd[solo]))
+      }
     }
   }
   ## Discrete scale
@@ -677,6 +712,5 @@ prepare_legend <- function(x, args, points = TRUE, lines = TRUE) {
     }
   }
 
-  leg <- utils::modifyList(leg, args)
-  do.call(graphics::legend, args = leg)
+  utils::modifyList(leg, args)
 }
