@@ -1,12 +1,8 @@
 Sys.setenv(LANGUAGE = "en") # Force locale
 
 if (at_home() && Sys.info()["sysname"] == "Linux") {
-  source("helpers.R")
   using("tinysnapshot")
-  options(tinysnapshot_device = "svglite")
-  options(tinysnapshot_height = 7) # inches
-  options(tinysnapshot_width = 7)
-  options(tinysnapshot_tol = 200) # pixels
+  source("helpers.R")
 
   data("iris")
 
@@ -21,7 +17,7 @@ if (at_home() && Sys.info()["sysname"] == "Linux") {
 
   plot_boot_col <- function() {
     viz_variables(Y, axes = c(1, 2), color = NULL, legend = list(x = "topleft"))
-    viz_tolerance(Y, margin = 2, level = c(0.68, 0.95))
+    viz_tolerance(Y, level = c(0.68, 0.95), color = NULL)
   }
   expect_snapshot_plot(plot_boot_col, "PCA_boot_col")
 }
